﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using ShakeGestures;

namespace PhoneAppTouchDrawWithGestures
{
    public partial class MainPage : PhoneApplicationPage
    {
        // Size of drawing brush
        private double drawingSize = 50;

        // Random number generator
        private Random random = new Random();

        // Current drawing color
        private Color drawingColor = Colors.Yellow;


        // Constructor
        public MainPage()
        {
            InitializeComponent();

            // Register for touch events
            Touch.FrameReported += new TouchFrameEventHandler(Touch_FrameReported);

            // Disable the frame rate counter (tiny numbers on the right side of the screen)
            Application.Current.Host.Settings.EnableFrameRateCounter = false;


            // Register shake event
            ShakeGesturesHelper.Instance.ShakeGesture += new EventHandler<ShakeGestureEventArgs>(Instance_ShakeGesture);

            // Set parameters: control sensitivity
            ShakeGesturesHelper.Instance.MinimumRequiredMovesForShake = 3;

            // Start shake detection
            ShakeGesturesHelper.Instance.Active = true;
        }


        // Event handler for shake events
        void Instance_ShakeGesture(object sender, ShakeGestureEventArgs e)
        {
            Deployment.Current.Dispatcher.BeginInvoke(() =>
            {
                if (e.ShakeType == ShakeType.X)
                {
                    // Erase the canvas when shaking sideways
                    this.canvas.Children.Clear();
                }
                else if (e.ShakeType == ShakeType.Z)
                {
                    // Shaking up and down
                    this.drawingColor = this.GetRandomColour();
                }
            });
        }


        void Touch_FrameReported(object sender, TouchFrameEventArgs e)
        {
            // Get all current touch points
            TouchPointCollection tpc = e.GetTouchPoints(this.canvas);

            // For each current touch point, do...
            foreach (TouchPoint tp in tpc)
            {
                // ...create a new ellipse, assign a random color, and set the default drawing size
                Ellipse ellipse = new Ellipse();
                ellipse.Fill = new SolidColorBrush(this.drawingColor);
                ellipse.Height = drawingSize;
                ellipse.Width = drawingSize;

                // ... then add this ellipse to the canvas as a visual element
                this.canvas.Children.Add(ellipse);

                // ... and set the position (left/top)
                ellipse.SetValue(Canvas.LeftProperty, (double)(tp.Position.X - drawingSize / 2.0));
                ellipse.SetValue(Canvas.TopProperty, (double)(tp.Position.Y - drawingSize / 2.0));
            }
        }


        // Get a random color
        private Color GetRandomColour()
        {
            return Color.FromArgb(
                (byte)255, 
                (byte)this.random.Next(255), 
                (byte)this.random.Next(255), 
                (byte)this.random.Next(255));
        }
    }
}